<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:ext="xalan://es.uca.xmleye.xpath.XPathPathManager"
 xmlns:xmls="http://www.uca.es/xmleye/xml-stylesheet"
 xmlns:ppacl2="http://www.uca.es/xmleye/ppACL2-stylesheet">

<!-- REGLA POR DEFECTO -->

<xsl:template match="*">
 <xsl:call-template name="skeleton">
   <xsl:with-param name="rtf">
     <xsl:apply-templates select="." mode="ppacl2_printnode"/>
   </xsl:with-param>
 </xsl:call-template>
</xsl:template>

<xsl:template match="script|includechk">
 <xsl:call-template name="skeleton">
   <xsl:with-param name="rtf">
     <xsl:apply-templates select="*" mode="ppacl2_printnode"/>
   </xsl:with-param>
 </xsl:call-template>
</xsl:template>

<xsl:template match="*[@isevent] | unknown">
 <xsl:call-template name="skeleton">
  <xsl:with-param name="rtf">

    <!-- Información básica -->
    <xsl:apply-templates select="." mode="ppacl2_printnode"/>

    <!-- Detalles -->
    <xsl:apply-templates select="*[not(self::summary)]" mode="ppacl2_printnode"/>

  </xsl:with-param>
 </xsl:call-template>
</xsl:template>

<xsl:template match="subgoal">
 <xsl:call-template name="skeleton">
   <xsl:with-param name="rtf">

     <!-- Información básica -->
     <xsl:apply-templates select="." mode="ppacl2_printnode"/>

     <!-- Información detallada -->
     <xsl:apply-templates select="." mode="ppacl2_printsubgoal"/>

     <h3 class="subsection"><xsl:value-of select="$ppacl2:output"/></h3>
     <xsl:apply-templates select="output" mode="ppacl2_printnode"/>

     <!-- Resumen de la siguiente submeta, si la tiene -->
     <xsl:apply-templates select="subgoal" mode="ppacl2_printnode"/>

   </xsl:with-param>
 </xsl:call-template>
</xsl:template>

<xsl:template match="dead_code">
  <xsl:call-template name="skeleton">
    <xsl:with-param name="rtf">
      <h2 class="section"><xsl:value-of select="$ppacl2:deadcode_report_title"/></h2>

      <xsl:choose>
        <xsl:when test="count(dead_event) > 0">
          <p>
            <xsl:value-of select="$ppacl2:deadcode_report"/>
          </p>

          <xsl:for-each-group select="key('uid', dead_event/@uid_event)"
                              group-by="local-name(.)">
            <h3 class="subsection"><xsl:value-of select="upper-case(local-name(current-group()[1]))"/></h3>

            <ul>
              <xsl:for-each select="current-group()">
                <li>
                  <a href="#xpointer({ext:getPath(., /)})">
                    <xsl:value-of select="@name"/>
                  </a>
                </li>
              </xsl:for-each>
            </ul>
          </xsl:for-each-group>
        </xsl:when>
        <xsl:otherwise>
          <p>
            There have been no events which could be considered as
            dead code.
          </p>
        </xsl:otherwise>
      </xsl:choose>

    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<!-- Regla usada para definir el esqueleto de toda salida -->

<xsl:template name="skeleton">
  <xsl:param name="rtf"/>

  <html>
   <body>

    <xsl:if test="ancestor::*">
      <h2 class="section"><xsl:value-of select="$ppacl2:ancestorevents"/></h2>
      <ol>
	<xsl:for-each select="ancestor::*[@isevent = '1' or self::script]">
	<li>
 	  <a href="#xpointer({ext:getPath(.,/)})">
	     <xsl:choose>
               <xsl:when test="@nodelabel"><xsl:value-of select="@nodelabel"/></xsl:when>
               <xsl:otherwise><xsl:value-of select="name(.)"/></xsl:otherwise>
             </xsl:choose>
          </a>
	</li> 
	</xsl:for-each>
      </ol>
      <hr/>
    </xsl:if>

    <xsl:copy-of select="$rtf"/>

    <hr/>

	<xsl:if test="not(@leaf = '1') and (child::*[not(@hidden = '1')] or text())">
	<h2 class="section"><xsl:copy-of select="$xmls:children"/></h2>

	<ol>
	   <xsl:for-each select="child::*[not(@hidden = '1')] | child::text()">

	   <xsl:choose>
	     <xsl:when test="self::text() and string-length(normalize-space(.))>0">
	       <li>
	         <i><xsl:copy-of select="concat($xmls:text,':')"/></i>
	         <xsl:value-of select="."/>
	       </li>
             </xsl:when>

	     <xsl:when test="not(self::text())">
	       <li><a href="#xpointer({ext:getPath(.,/)})">
		 <xsl:choose>
                   <xsl:when test="@nodelabel"><xsl:value-of select="@nodelabel"/></xsl:when>
                   <xsl:otherwise><xsl:value-of select="name(.)"/></xsl:otherwise>
                 </xsl:choose>
	       </a></li>
	     </xsl:when>

	   </xsl:choose>
	 </xsl:for-each>
	</ol>
	</xsl:if>

   </body>
  </html>
</xsl:template>


</xsl:stylesheet>
